@@ -23,7 +23,7 @@ Net::TacacsPlus::Client - Tacacs+ client library
 	{
 		print "Authorization successful.\n";
 		print "Arguments received from server:\n";
-		print join("\n", @{$args_response});
+		print join("\n", @args_response);
 	} else {
 		print "Authorization failed: " . $tac->errmsg() . "\n";
 	}
@@ -471,7 +471,7 @@ sub DESTROY {
 
 =head1 AUTHOR
 
-Jozef Kutej - E<lt>jozef@kutej.netE<gt>
+Jozef Kutej - E<lt>jkutej@cpan.orgE<gt>
 
 Authorization and Accounting contributed by Rubio Vaughan E<lt>rubio@passim.netE<gt>
 
@@ -483,8 +483,6 @@ Authorization and Accounting contributed by Rubio Vaughan E<lt>rubio@passim.netE
 
 tac-rfc.1.78.txt, Net::TacacsPlus::Packet
 
-Net::TacacsPlus Trac page L<http://trac.cle.sk/Net-TacacsPlus/>
-
 Complete client script C<Net-TacacsPlus/examples/client.pl>.
 
 =head1 TODO
